@@ -1,6 +1,3 @@
-#ifndef CINSTALL_ANTIVIRUS_H
-#define CINSTALL_ANTIVIRUS_H
-
 /*
  * Copyright (c) 2001, Gary R. Van Sickle.
  *
@@ -16,6 +13,9 @@
  *
  */
 
+#ifndef SETUP_ANTIVIRUS_H
+#define SETUP_ANTIVIRUS_H
+
 // This is the header for the AntiVirusPage class, which lets the user
 // disable their virus scanner if needed.
 
@@ -41,10 +41,11 @@ public:
   bool Create ();
 
   virtual void OnActivate ();
+  virtual bool wantsActivation() const;
   virtual void OnDeactivate ();
   virtual long OnNext ();
   virtual long OnBack ();
   virtual long OnUnattended ();
 };
 
-#endif /* CINSTALL_ANTIVIRUS_H */
+#endif /* SETUP_ANTIVIRUS_H */
