@@ -13,11 +13,12 @@
  *
  */
 
-#ifndef _PICKVIEW_H_
-#define _PICKVIEW_H_
+#ifndef SETUP_PICKVIEW_H
+#define SETUP_PICKVIEW_H
 
 #include "win32.h"
 #include "String++.h"
+#include "window.h"
 
 #define HMARGIN 10
 #define ROW_MARGIN      5
@@ -25,16 +26,20 @@
 #define RTARROW_WIDTH 11
 #define SPIN_WIDTH 11
 #define NEW_COL_SIZE_SLOP (ICON_MARGIN + SPIN_WIDTH + RTARROW_WIDTH)
-
 #define CHECK_SIZE      11
 
+#define CATEGORY_EXPANDED  0
+#define CATEGORY_COLLAPSED 1
+
 class PickView;
 #include "PickCategoryLine.h"
 #include "package_meta.h"
 
-class PickView
+class PickView : public Window
 {
 public:
+  virtual bool Create (Window * Parent = NULL, DWORD Style = WS_OVERLAPPEDWINDOW | WS_VISIBLE | WS_CLIPCHILDREN, RECT * r = NULL);
+  virtual bool registerWindowClass ();
   class views;
   class Header;
   int num_columns;
@@ -42,15 +47,24 @@ public:
   {
     return view_mode;
   };
+  void defaultTrust (trusts trust);
   void set_view_mode (views _mode);
+  void setViewMode (PickView::views mode);
+  void paint (HWND hwnd);
+  LRESULT CALLBACK list_click (HWND hwnd, BOOL dblclk, int x, int y, UINT hitCode);
+  LRESULT CALLBACK list_hscroll (HWND hwnd, HWND hctl, UINT code, int pos);
+  LRESULT CALLBACK list_vscroll (HWND hwnd, HWND hctl, UINT code, int pos);
+  virtual LRESULT WindowProc (UINT uMsg, WPARAM wParam, LPARAM lParam);
   Header *headers;
-  PickView (views mode, HWND listview, Category & cat);
+  PickView (Category & cat);
+  void init(views _mode);
   ~PickView();
   const char *mode_caption ();
   void insert_pkg (packagemeta &);
   void insert_category (Category *, bool);
   void clear_view (void);
   int click (int row, int x);
+  void refresh();
   int current_col;
   int new_col;
   int bintick_col;
@@ -117,7 +131,7 @@ public:
   };
 
 private:
-  HWND listview;
+  static ATOM WindowClassAtom;
   HWND listheader;
   views view_mode;
   void set_headers ();
@@ -126,4 +140,4 @@ private:
       int column);
 };
 
-#endif // _PICKVIEW_H_
+#endif /* SETUP_PICKVIEW_H */
