@@ -13,19 +13,25 @@
  *
  */
 
-/* A collection of user-related settings */
+#ifndef SETUP_USERSETTINGS_H
+#define SETUP_USERSETTINGS_H
 
-#ifndef _USERSETTINGS_H_
-#define _USERSETTINGS_H_
+/* A collection of user-related settings */
 
 #include <vector>
 
+class io_stream;
 class UserSetting;
+class String;
 class UserSettings {
   public:
     static UserSettings &Instance();
     void registerSetting(UserSetting &);
     void deRegisterSetting(UserSetting &);
+    void loadAllSettings();
+    void saveAllSettings();
+    io_stream * settingFileForLoad(String const &relativeName) const;
+    io_stream * settingFileForSave(String const &relativeName) const;
   private:
     static UserSettings Instance_;
     typedef std::vector<UserSetting *> Settings;
@@ -34,4 +40,4 @@ class UserSettings {
     Settings settings;
 };
 
-#endif /* _USERSETTINGS_H_ */
+#endif /* SETUP_USERSETTINGS_H */
