@@ -18,7 +18,7 @@
 
 #if 0
 static const char *cvsid =
-  "\n%%% $Id: filemanip.cc,v 2.11 2002/07/05 01:59:34 rbcollins Exp $\n";
+  "\n%%% $Id: filemanip.cc,v 2.12 2003/07/30 23:10:35 igor Exp $\n";
 #endif
 
 #include <stdio.h>
@@ -166,11 +166,5 @@ trail (const char *haystack, const char *needle)
 String
 backslash (String const & aString)
 {
-  char * tempString = aString.cstr();
-  for (char *t = tempString; *t; t++)
-    if (*t == '/')
-      *t = '\\';
-  String theString(tempString);
-  delete[] tempString;
-  return theString;
+  return aString.replace ('/', '\\');
 }
