@@ -13,6 +13,9 @@
  *
  */
 
+#ifndef SETUP_FILEMANIP_H
+#define SETUP_FILEMANIP_H
+
 #include "String++.h"
 
 extern int find_tar_ext (const char *path);
@@ -31,3 +34,5 @@ String base (String const &);
 size_t get_file_size (String const &);
 String backslash (String const &);
 const char * trail (const char *, const char *);
+
+#endif /* SETUP_FILEMANIP_H */
