@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 1.875b.  */
+/* A Bison parser, made from /home/RobertC/src/cygwin/setup/iniparse.y, by GNU bison 1.75.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -34,13 +34,10 @@
    USER NAME SPACE" below.  */
 
 /* Identify Bison output.  */
-#define YYBISON 1
-
-/* Skeleton name.  */
-#define YYSKELETON_NAME "yacc.c"
+#define YYBISON	1
 
 /* Pure parsers.  */
-#define YYPURE 0
+#define YYPURE	0
 
 /* Using locations.  */
 #define YYLSP_NEEDED 0
@@ -176,7 +173,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 1 "../iniparse.y"
+#line 1 "/home/RobertC/src/cygwin/setup/iniparse.y"
 
 /*
  * Copyright (c) 2000, Red Hat, Inc.
@@ -234,20 +231,29 @@ void add_correct_version();
 # define YYERROR_VERBOSE 0
 #endif
 
-#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-typedef int YYSTYPE;
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
-# define YYSTYPE_IS_DECLARED 1
+#ifndef YYSTYPE
+typedef int yystype;
+# define YYSTYPE yystype
 # define YYSTYPE_IS_TRIVIAL 1
 #endif
 
-
+#ifndef YYLTYPE
+typedef struct yyltype
+{
+  int first_line;
+  int first_column;
+  int last_line;
+  int last_column;
+} yyltype;
+# define YYLTYPE yyltype
+# define YYLTYPE_IS_TRIVIAL 1
+#endif
 
 /* Copy the second part of user declarations.  */
 
 
-/* Line 214 of yacc.c.  */
-#line 251 "iniparse.cc"
+/* Line 213 of /usr/share/bison/yacc.c.  */
+#line 257 "iniparse.cc"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -283,7 +289,7 @@ typedef int YYSTYPE;
 
 #if (! defined (yyoverflow) \
      && (! defined (__cplusplus) \
-	 || (YYSTYPE_IS_TRIVIAL)))
+	 || (YYLTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
@@ -293,13 +299,13 @@ union yyalloc
   };
 
 /* The size of the maximum gap between one aligned stack and the next.  */
-# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
+# define YYSTACK_GAP_MAX (sizeof (union yyalloc) - 1)
 
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
 # define YYSTACK_BYTES(N) \
      ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
-      + YYSTACK_GAP_MAXIMUM)
+      + YYSTACK_GAP_MAX)
 
 /* Copy COUNT objects from FROM to TO.  The source and destination do
    not overlap.  */
@@ -313,7 +319,7 @@ union yyalloc
 	{					\
 	  register YYSIZE_T yyi;		\
 	  for (yyi = 0; yyi < (Count); yyi++)	\
-	    (To)[yyi] = (From)[yyi];		\
+	    (To)[yyi] = (From)[yyi];	\
 	}					\
       while (0)
 #  endif
@@ -330,7 +336,7 @@ union yyalloc
 	YYSIZE_T yynewbytes;						\
 	YYCOPY (&yyptr->Stack, Stack, yysize);				\
 	Stack = &yyptr->Stack;						\
-	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
+	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAX;	\
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
     while (0)
@@ -345,7 +351,6 @@ union yyalloc
 
 /* YYFINAL -- State number of the termination state. */
 #define YYFINAL  3
-/* YYLAST -- Last index in YYTABLE.  */
 #define YYLAST   162
 
 /* YYNTOKENS -- Number of terminals. */
@@ -361,8 +366,8 @@ union yyalloc
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   315
 
-#define YYTRANSLATE(YYX) 						\
-  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
+#define YYTRANSLATE(X) \
+  ((unsigned)(X) <= YYMAXUTOK ? yytranslate[X] : YYUNDEFTOK)
 
 /* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
 static const unsigned char yytranslate[] =
@@ -631,7 +636,7 @@ static const yysigned_char yypgoto[] =
 /* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
    positive, shift that token.  If negative, reduce the rule which
    number is the opposite.  If zero, do what YYDEFACT says.
-   If YYTABLE_NINF, syntax error.  */
+   If YYTABLE_NINF, parse error.  */
 #define YYTABLE_NINF -14
 static const short yytable[] =
 {
@@ -719,14 +724,13 @@ static const unsigned char yystos[] =
 
 #define yyerrok		(yyerrstatus = 0)
 #define yyclearin	(yychar = YYEMPTY)
-#define YYEMPTY		(-2)
+#define YYEMPTY		-2
 #define YYEOF		0
 
 #define YYACCEPT	goto yyacceptlab
 #define YYABORT		goto yyabortlab
 #define YYERROR		goto yyerrlab1
 
-
 /* Like YYERROR except do call yyerror.  This remains here temporarily
    to ease the transition to the new meaning of YYERROR, for GCC.
    Once GCC version 2 has supplanted version 1, this can go.  */
@@ -741,13 +745,13 @@ do								\
     {								\
       yychar = (Token);						\
       yylval = (Value);						\
-      yytoken = YYTRANSLATE (yychar);				\
+      yychar1 = YYTRANSLATE (yychar);				\
       YYPOPSTACK;						\
       goto yybackup;						\
     }								\
   else								\
     { 								\
-      yyerror ("syntax error: cannot back up");\
+      yyerror ("syntax error: cannot back up");			\
       YYERROR;							\
     }								\
 while (0)
@@ -759,7 +763,7 @@ while (0)
    are run).  */
 
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)         \
+# define YYLLOC_DEFAULT(Current, Rhs, N)           \
   Current.first_line   = Rhs[1].first_line;      \
   Current.first_column = Rhs[1].first_column;    \
   Current.last_line    = Rhs[N].last_line;       \
@@ -768,11 +772,7 @@ while (0)
 
 /* YYLEX -- calling `yylex' with the right arguments.  */
 
-#ifdef YYLEX_PARAM
-# define YYLEX yylex (YYLEX_PARAM)
-#else
-# define YYLEX yylex ()
-#endif
+#define YYLEX	yylex ()
 
 /* Enable debugging if requested.  */
 #if YYDEBUG
@@ -787,93 +787,19 @@ do {						\
   if (yydebug)					\
     YYFPRINTF Args;				\
 } while (0)
-
 # define YYDSYMPRINT(Args)			\
 do {						\
   if (yydebug)					\
     yysymprint Args;				\
 } while (0)
-
-# define YYDSYMPRINTF(Title, Token, Value, Location)		\
-do {								\
-  if (yydebug)							\
-    {								\
-      YYFPRINTF (stderr, "%s ", Title);				\
-      yysymprint (stderr, 					\
-                  Token, Value);	\
-      YYFPRINTF (stderr, "\n");					\
-    }								\
-} while (0)
-
-/*------------------------------------------------------------------.
-| yy_stack_print -- Print the state stack from its BOTTOM up to its |
-| TOP (cinluded).                                                   |
-`------------------------------------------------------------------*/
-
-#if defined (__STDC__) || defined (__cplusplus)
-static void
-yy_stack_print (short *bottom, short *top)
-#else
-static void
-yy_stack_print (bottom, top)
-    short *bottom;
-    short *top;
-#endif
-{
-  YYFPRINTF (stderr, "Stack now");
-  for (/* Nothing. */; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
-  YYFPRINTF (stderr, "\n");
-}
-
-# define YY_STACK_PRINT(Bottom, Top)				\
-do {								\
-  if (yydebug)							\
-    yy_stack_print ((Bottom), (Top));				\
-} while (0)
-
-
-/*------------------------------------------------.
-| Report that the YYRULE is going to be reduced.  |
-`------------------------------------------------*/
-
-#if defined (__STDC__) || defined (__cplusplus)
-static void
-yy_reduce_print (int yyrule)
-#else
-static void
-yy_reduce_print (yyrule)
-    int yyrule;
-#endif
-{
-  int yyi;
-  unsigned int yylno = yyrline[yyrule];
-  YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
-             yyrule - 1, yylno);
-  /* Print the symbols being reduced, and their result.  */
-  for (yyi = yyprhs[yyrule]; 0 <= yyrhs[yyi]; yyi++)
-    YYFPRINTF (stderr, "%s ", yytname [yyrhs[yyi]]);
-  YYFPRINTF (stderr, "-> %s\n", yytname [yyr1[yyrule]]);
-}
-
-# define YY_REDUCE_PRINT(Rule)		\
-do {					\
-  if (yydebug)				\
-    yy_reduce_print (Rule);		\
-} while (0)
-
 /* Nonzero means print parse trace.  It is left uninitialized so that
    multiple parsers can coexist.  */
 int yydebug;
 #else /* !YYDEBUG */
 # define YYDPRINTF(Args)
 # define YYDSYMPRINT(Args)
-# define YYDSYMPRINTF(Title, Token, Value, Location)
-# define YY_STACK_PRINT(Bottom, Top)
-# define YY_REDUCE_PRINT(Rule)
 #endif /* !YYDEBUG */
 
-
 /* YYINITDEPTH -- initial size of the parser's stacks.  */
 #ifndef	YYINITDEPTH
 # define YYINITDEPTH 200
@@ -952,85 +878,95 @@ yystpcpy (yydest, yysrc)
 
 
 #if YYDEBUG
-/*--------------------------------.
-| Print this symbol on YYOUTPUT.  |
-`--------------------------------*/
+/*-----------------------------.
+| Print this symbol on YYOUT.  |
+`-----------------------------*/
 
+static void
 #if defined (__STDC__) || defined (__cplusplus)
-static void
-yysymprint (FILE *yyoutput, int yytype, YYSTYPE *yyvaluep)
+yysymprint (FILE* yyout, int yytype, YYSTYPE yyvalue)
 #else
-static void
-yysymprint (yyoutput, yytype, yyvaluep)
-    FILE *yyoutput;
+yysymprint (yyout, yytype, yyvalue)
+    FILE* yyout;
     int yytype;
-    YYSTYPE *yyvaluep;
+    YYSTYPE yyvalue;
 #endif
 {
   /* Pacify ``unused variable'' warnings.  */
-  (void) yyvaluep;
+  (void) yyvalue;
 
   if (yytype < YYNTOKENS)
     {
-      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
+      YYFPRINTF (yyout, "token %s (", yytname[yytype]);
 # ifdef YYPRINT
-      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+      YYPRINT (yyout, yytoknum[yytype], yyvalue);
 # endif
     }
   else
-    YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);
+    YYFPRINTF (yyout, "nterm %s (", yytname[yytype]);
 
   switch (yytype)
     {
       default:
         break;
     }
-  YYFPRINTF (yyoutput, ")");
+  YYFPRINTF (yyout, ")");
 }
+#endif /* YYDEBUG. */
+
 
-#endif /* ! YYDEBUG */
 /*-----------------------------------------------.
 | Release the memory associated to this symbol.  |
 `-----------------------------------------------*/
 
+static void
 #if defined (__STDC__) || defined (__cplusplus)
-static void
-yydestruct (int yytype, YYSTYPE *yyvaluep)
+yydestruct (int yytype, YYSTYPE yyvalue)
 #else
-static void
-yydestruct (yytype, yyvaluep)
+yydestruct (yytype, yyvalue)
     int yytype;
-    YYSTYPE *yyvaluep;
+    YYSTYPE yyvalue;
 #endif
 {
   /* Pacify ``unused variable'' warnings.  */
-  (void) yyvaluep;
+  (void) yyvalue;
 
   switch (yytype)
     {
-
       default:
         break;
     }
 }
+
 
 
-/* Prevent warnings from -Wmissing-prototypes.  */
+/* The user can define YYPARSE_PARAM as the name of an argument to be passed
+   into yyparse.  The argument should have type void *.
+   It should actually point to an object.
+   Grammar actions can access the variable by casting it
+   to the proper pointer type.  */
 
 #ifdef YYPARSE_PARAM
 # if defined (__STDC__) || defined (__cplusplus)
-int yyparse (void *YYPARSE_PARAM);
+#  define YYPARSE_PARAM_ARG void *YYPARSE_PARAM
+#  define YYPARSE_PARAM_DECL
 # else
-int yyparse ();
+#  define YYPARSE_PARAM_ARG YYPARSE_PARAM
+#  define YYPARSE_PARAM_DECL void *YYPARSE_PARAM;
 # endif
-#else /* ! YYPARSE_PARAM */
-#if defined (__STDC__) || defined (__cplusplus)
-int yyparse (void);
-#else
-int yyparse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
+#else /* !YYPARSE_PARAM */
+# define YYPARSE_PARAM_ARG
+# define YYPARSE_PARAM_DECL
+#endif /* !YYPARSE_PARAM */
 
+/* Prevent warning if -Wstrict-prototypes.  */
+#ifdef __GNUC__
+# ifdef YYPARSE_PARAM
+int yyparse (void *);
+# else
+int yyparse (void);
+# endif
+#endif
 
 
 /* The lookahead symbol.  */
@@ -1039,32 +975,13 @@ int yychar;
 /* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
-/* Number of syntax errors so far.  */
+/* Number of parse errors so far.  */
 int yynerrs;
 
 
-
-/*----------.
-| yyparse.  |
-`----------*/
-
-#ifdef YYPARSE_PARAM
-# if defined (__STDC__) || defined (__cplusplus)
-int yyparse (void *YYPARSE_PARAM)
-# else
-int yyparse (YYPARSE_PARAM)
-  void *YYPARSE_PARAM;
-# endif
-#else /* ! YYPARSE_PARAM */
-#if defined (__STDC__) || defined (__cplusplus)
 int
-yyparse (void)
-#else
-int
-yyparse ()
-
-#endif
-#endif
+yyparse (YYPARSE_PARAM_ARG)
+     YYPARSE_PARAM_DECL
 {
   
   register int yystate;
@@ -1073,7 +990,7 @@ yyparse ()
   /* Number of tokens to shift before error messages enabled.  */
   int yyerrstatus;
   /* Lookahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  int yychar1 = 0;
 
   /* Three stacks and their tools:
      `yyss': related to states,
@@ -1137,7 +1054,7 @@ yyparse ()
  yysetstate:
   *yyssp = yystate;
 
-  if (yyss + yystacksize - 1 <= yyssp)
+  if (yyssp >= yyss + yystacksize - 1)
     {
       /* Get the current used size of the three stacks, in elements.  */
       YYSIZE_T yysize = yyssp - yyss + 1;
@@ -1169,10 +1086,10 @@ yyparse ()
       goto yyoverflowlab;
 # else
       /* Extend the stack our own way.  */
-      if (YYMAXDEPTH <= yystacksize)
+      if (yystacksize >= YYMAXDEPTH)
 	goto yyoverflowlab;
       yystacksize *= 2;
-      if (YYMAXDEPTH < yystacksize)
+      if (yystacksize > YYMAXDEPTH)
 	yystacksize = YYMAXDEPTH;
 
       {
@@ -1198,7 +1115,7 @@ yyparse ()
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
-      if (yyss + yystacksize - 1 <= yyssp)
+      if (yyssp >= yyss + yystacksize - 1)
 	YYABORT;
     }
 
@@ -1223,28 +1140,39 @@ yybackup:
 
   /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
+  /* yychar is either YYEMPTY or YYEOF
+     or a valid token in external form.  */
+
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
       yychar = YYLEX;
     }
 
-  if (yychar <= YYEOF)
+  /* Convert token to internal form (in yychar1) for indexing tables with.  */
+
+  if (yychar <= 0)		/* This means end of input.  */
     {
-      yychar = yytoken = YYEOF;
+      yychar1 = 0;
+      yychar = YYEOF;		/* Don't call YYLEX any more.  */
+
       YYDPRINTF ((stderr, "Now at end of input.\n"));
     }
   else
     {
-      yytoken = YYTRANSLATE (yychar);
-      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
+      yychar1 = YYTRANSLATE (yychar);
+
+      /* We have to keep this `#if YYDEBUG', since we use variables
+	 which are defined only if `YYDEBUG' is set.  */
+      YYDPRINTF ((stderr, "Next token is "));
+      YYDSYMPRINT ((stderr, yychar1, yylval));
+      YYDPRINTF ((stderr, "\n"));
     }
 
-  /* If the proper action on seeing token YYTOKEN is to reduce or to
+  /* If the proper action on seeing token YYCHAR1 is to reduce or to
      detect an error, take that action.  */
-  yyn += yytoken;
-  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
+  yyn += yychar1;
+  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yychar1)
     goto yydefault;
   yyn = yytable[yyn];
   if (yyn <= 0)
@@ -1259,7 +1187,8 @@ yybackup:
     YYACCEPT;
 
   /* Shift the lookahead token.  */
-  YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));
+  YYDPRINTF ((stderr, "Shifting token %d (%s), ",
+	      yychar, yytname[yychar1]));
 
   /* Discard the token being shifted unless it is eof.  */
   if (yychar != YYEOF)
@@ -1305,313 +1234,338 @@ yyreduce:
   yyval = yyvsp[1-yylen];
 
 
-  YY_REDUCE_PRINT (yyn);
+
+#if YYDEBUG
+  /* We have to keep this `#if YYDEBUG', since we use variables which
+     are defined only if `YYDEBUG' is set.  */
+  if (yydebug)
+    {
+      int yyi;
+
+      YYFPRINTF (stderr, "Reducing via rule %d (line %d), ",
+		 yyn - 1, yyrline[yyn]);
+
+      /* Print the symbols being reduced, and their result.  */
+      for (yyi = yyprhs[yyn]; yyrhs[yyi] >= 0; yyi++)
+	YYFPRINTF (stderr, "%s ", yytname[yyrhs[yyi]]);
+      YYFPRINTF (stderr, " -> %s\n", yytname[yyr1[yyn]]);
+    }
+#endif
   switch (yyn)
     {
         case 5:
-#line 70 "../iniparse.y"
-    { iniBuilder->buildTimestamp (yyvsp[0]); ;}
+#line 70 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildTimestamp (yyvsp[0]); }
     break;
 
   case 7:
-#line 71 "../iniparse.y"
-    { iniBuilder->buildVersion (yyvsp[0]); ;}
+#line 71 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildVersion (yyvsp[0]); }
     break;
 
   case 14:
-#line 87 "../iniparse.y"
-    { iniBuilder->buildPackage (yyvsp[0]); ;}
+#line 87 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackage (yyvsp[0]); }
     break;
 
   case 15:
-#line 88 "../iniparse.y"
-    { iniBuilder->buildPackage (yyvsp[0]); ;}
+#line 88 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackage (yyvsp[0]); }
     break;
 
   case 18:
-#line 96 "../iniparse.y"
-    { iniBuilder->buildPackageVersion (yyvsp[-1]); ;}
+#line 96 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageVersion (yyvsp[-1]); }
     break;
 
   case 19:
-#line 97 "../iniparse.y"
-    { iniBuilder->buildPackageSDesc(yyvsp[-1]); ;}
+#line 97 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageSDesc(yyvsp[-1]); }
     break;
 
   case 20:
-#line 98 "../iniparse.y"
-    { iniBuilder->buildPackageLDesc(yyvsp[-1]); ;}
+#line 98 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageLDesc(yyvsp[-1]); }
     break;
 
   case 21:
-#line 99 "../iniparse.y"
-    { iniBuilder->buildPackageTrust (TRUST_PREV); ;}
+#line 99 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageTrust (TRUST_PREV); }
     break;
 
   case 22:
-#line 100 "../iniparse.y"
-    { iniBuilder->buildPackageTrust (TRUST_CURR); ;}
+#line 100 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageTrust (TRUST_CURR); }
     break;
 
   case 23:
-#line 101 "../iniparse.y"
-    { iniBuilder->buildPackageTrust (TRUST_TEST); ;}
+#line 101 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageTrust (TRUST_TEST); }
     break;
 
   case 24:
-#line 102 "../iniparse.y"
-    { iniBuilder->buildPriority (yyvsp[-1]); ;}
+#line 102 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPriority (yyvsp[-1]); }
     break;
 
   case 25:
-#line 103 "../iniparse.y"
-    { iniBuilder->buildInstalledSize (yyvsp[-1]); ;}
+#line 103 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildInstalledSize (yyvsp[-1]); }
     break;
 
   case 26:
-#line 104 "../iniparse.y"
-    { iniBuilder->buildMaintainer (yyvsp[-1]); ;}
+#line 104 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildMaintainer (yyvsp[-1]); }
     break;
 
   case 27:
-#line 105 "../iniparse.y"
-    { iniBuilder->buildArchitecture (yyvsp[-1]); ;}
+#line 105 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildArchitecture (yyvsp[-1]); }
     break;
 
   case 28:
-#line 106 "../iniparse.y"
-    { iniBuilder->buildInstallSize(yyvsp[-1]); ;}
+#line 106 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildInstallSize(yyvsp[-1]); }
     break;
 
   case 29:
-#line 107 "../iniparse.y"
-    { /* TODO */ ;}
+#line 107 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { /* TODO */ }
     break;
 
   case 30:
-#line 108 "../iniparse.y"
-    { /* TODO */ ;}
+#line 108 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { /* TODO */ }
     break;
 
   case 31:
-#line 109 "../iniparse.y"
-    { /* TODO */ ;}
+#line 109 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { /* TODO */ }
     break;
 
   case 32:
-#line 110 "../iniparse.y"
-    { iniBuilder->buildInstallMD5 ((unsigned char *)yyvsp[-1]); ;}
+#line 110 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildInstallMD5 ((unsigned char *)yyvsp[-1]); }
     break;
 
   case 35:
-#line 113 "../iniparse.y"
-    { iniBuilder->buildPackageInstall (yyvsp[0]); ;}
+#line 113 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageInstall (yyvsp[0]); }
     break;
 
   case 37:
-#line 114 "../iniparse.y"
-    {iniBuilder->buildPackageSource (yyvsp[-3], yyvsp[-2]);;}
+#line 114 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    {iniBuilder->buildPackageSource (yyvsp[-3], yyvsp[-2]);}
     break;
 
   case 38:
-#line 115 "../iniparse.y"
-    { iniBuilder->buildBeginProvides(); ;}
+#line 115 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildBeginProvides(); }
     break;
 
   case 40:
-#line 116 "../iniparse.y"
-    { iniBuilder->buildBeginBinary (); ;}
+#line 116 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildBeginBinary (); }
     break;
 
   case 42:
-#line 117 "../iniparse.y"
-    { iniBuilder->buildBeginConflicts(); ;}
+#line 117 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildBeginConflicts(); }
     break;
 
   case 44:
-#line 118 "../iniparse.y"
-    { iniBuilder->buildBeginDepends(); ;}
+#line 118 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildBeginDepends(); }
     break;
 
   case 46:
-#line 119 "../iniparse.y"
-    { iniBuilder->buildBeginDepends(); ;}
+#line 119 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildBeginDepends(); }
     break;
 
   case 48:
-#line 120 "../iniparse.y"
-    { iniBuilder->buildBeginPreDepends(); ;}
+#line 120 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildBeginPreDepends(); }
     break;
 
   case 50:
-#line 121 "../iniparse.y"
-    { iniBuilder->buildBeginRecommends(); ;}
+#line 121 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildBeginRecommends(); }
     break;
 
   case 52:
-#line 122 "../iniparse.y"
-    { iniBuilder->buildBeginSuggests(); ;}
+#line 122 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildBeginSuggests(); }
     break;
 
   case 54:
-#line 123 "../iniparse.y"
-    { iniBuilder->buildBeginReplaces(); ;}
+#line 123 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildBeginReplaces(); }
     break;
 
   case 56:
-#line 124 "../iniparse.y"
-    { iniBuilder->buildBeginBuildDepends(); ;}
+#line 124 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildBeginBuildDepends(); }
     break;
 
   case 60:
-#line 127 "../iniparse.y"
+#line 127 "/home/RobertC/src/cygwin/setup/iniparse.y"
     { yyerror (String("unrecognized line ") 
 					  + yylineno 
 					  + " (do you have the latest setup?)");
-				;}
+				}
     break;
 
   case 62:
-#line 134 "../iniparse.y"
-    { iniBuilder->buildArchitecture (yyvsp[0]); ;}
+#line 134 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildArchitecture (yyvsp[0]); }
     break;
 
   case 64:
-#line 138 "../iniparse.y"
-    { iniBuilder->buildPackageCategory (yyvsp[0]); ;}
+#line 138 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageCategory (yyvsp[0]); }
     break;
 
   case 66:
-#line 142 "../iniparse.y"
-    { iniBuilder->buildInstallSize(yyvsp[-1]); ;}
+#line 142 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildInstallSize(yyvsp[-1]); }
     break;
 
   case 68:
-#line 146 "../iniparse.y"
-    { iniBuilder->buildInstallMD5 ((unsigned char *)yyvsp[0]);;}
+#line 146 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildInstallMD5 ((unsigned char *)yyvsp[0]);}
     break;
 
   case 70:
-#line 150 "../iniparse.y"
-    { iniBuilder->buildSourceMD5 ((unsigned char *)yyvsp[0]); ;}
+#line 150 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildSourceMD5 ((unsigned char *)yyvsp[0]); }
     break;
 
   case 71:
-#line 154 "../iniparse.y"
-    { iniBuilder->buildSourceName (yyvsp[0]); ;}
+#line 154 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildSourceName (yyvsp[0]); }
     break;
 
   case 74:
-#line 158 "../iniparse.y"
-    { iniBuilder->buildSourceNameVersion (yyvsp[-1]); ;}
+#line 158 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildSourceNameVersion (yyvsp[-1]); }
     break;
 
   case 76:
-#line 162 "../iniparse.y"
-    { iniBuilder->buildDescription (yyvsp[-1]); ;}
+#line 162 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildDescription (yyvsp[-1]); }
     break;
 
   case 77:
-#line 163 "../iniparse.y"
-    { iniBuilder->buildDescription (yyvsp[-1]); ;}
+#line 163 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildDescription (yyvsp[-1]); }
     break;
 
   case 78:
-#line 167 "../iniparse.y"
-    { iniBuilder->buildPackageListAndNode(); ;}
+#line 167 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageListAndNode(); }
     break;
 
   case 80:
-#line 168 "../iniparse.y"
-    { iniBuilder->buildPackageListAndNode(); ;}
+#line 168 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageListAndNode(); }
     break;
 
   case 82:
-#line 172 "../iniparse.y"
-    { iniBuilder->buildPackageListOrNode(yyvsp[0]); ;}
+#line 172 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageListOrNode(yyvsp[0]); }
     break;
 
   case 83:
-#line 173 "../iniparse.y"
-    { iniBuilder->buildPackageListOrNode(yyvsp[0]); ;}
+#line 173 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageListOrNode(yyvsp[0]); }
     break;
 
   case 84:
-#line 177 "../iniparse.y"
-    { iniBuilder->buildPackageListAndNode(); ;}
+#line 177 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageListAndNode(); }
     break;
 
   case 86:
-#line 178 "../iniparse.y"
-    { iniBuilder->buildPackageListAndNode(); ;}
+#line 178 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageListAndNode(); }
     break;
 
   case 88:
-#line 182 "../iniparse.y"
-    { iniBuilder->buildPackageListAndNode(); ;}
+#line 182 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageListAndNode(); }
     break;
 
   case 90:
-#line 183 "../iniparse.y"
-    { iniBuilder->buildPackageListAndNode(); ;}
+#line 183 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageListAndNode(); }
     break;
 
   case 95:
-#line 193 "../iniparse.y"
-    { iniBuilder->buildPackageListOrNode(yyvsp[0]); ;}
+#line 193 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageListOrNode(yyvsp[0]); }
     break;
 
   case 97:
-#line 194 "../iniparse.y"
-    { iniBuilder->buildPackageListOrNode(yyvsp[0]); ;}
+#line 194 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageListOrNode(yyvsp[0]); }
     break;
 
   case 100:
-#line 198 "../iniparse.y"
-    { iniBuilder->buildPackageListOperatorVersion (yyvsp[-1]); ;}
+#line 198 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageListOperatorVersion (yyvsp[-1]); }
     break;
 
   case 101:
-#line 202 "../iniparse.y"
-    { iniBuilder->buildPackageListOperator (PackageSpecification::Equals); ;}
+#line 202 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageListOperator (PackageSpecification::Equals); }
     break;
 
   case 102:
-#line 203 "../iniparse.y"
-    { iniBuilder->buildPackageListOperator (PackageSpecification::LessThan); ;}
+#line 203 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageListOperator (PackageSpecification::LessThan); }
     break;
 
   case 103:
-#line 204 "../iniparse.y"
-    { iniBuilder->buildPackageListOperator (PackageSpecification::MoreThan); ;}
+#line 204 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageListOperator (PackageSpecification::MoreThan); }
     break;
 
   case 104:
-#line 205 "../iniparse.y"
-    { iniBuilder->buildPackageListOperator (PackageSpecification::LessThanEquals); ;}
+#line 205 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageListOperator (PackageSpecification::LessThanEquals); }
     break;
 
   case 105:
-#line 206 "../iniparse.y"
-    { iniBuilder->buildPackageListOperator (PackageSpecification::MoreThanEquals); ;}
+#line 206 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildPackageListOperator (PackageSpecification::MoreThanEquals); }
     break;
 
   case 111:
-#line 219 "../iniparse.y"
-    { iniBuilder->buildSourceFile ((unsigned char *)yyvsp[-2], yyvsp[-1], yyvsp[0]);  ;}
+#line 219 "/home/RobertC/src/cygwin/setup/iniparse.y"
+    { iniBuilder->buildSourceFile ((unsigned char *)yyvsp[-2], yyvsp[-1], yyvsp[0]);  }
     break;
 
 
     }
 
-/* Line 999 of yacc.c.  */
-#line 1609 "iniparse.cc"
+/* Line 1016 of /usr/share/bison/yacc.c.  */
+#line 1554 "iniparse.cc"
 
   yyvsp -= yylen;
   yyssp -= yylen;
 
 
-  YY_STACK_PRINT (yyss, yyssp);
+#if YYDEBUG
+  if (yydebug)
+    {
+      short *yyssp1 = yyss - 1;
+      YYFPRINTF (stderr, "state stack now");
+      while (yyssp1 != yyssp)
+	YYFPRINTF (stderr, " %d", *++yyssp1);
+      YYFPRINTF (stderr, "\n");
+    }
+#endif
 
   *++yyvsp = yyval;
 
@@ -1646,63 +1600,55 @@ yyerrlab:
 	{
 	  YYSIZE_T yysize = 0;
 	  int yytype = YYTRANSLATE (yychar);
-	  const char* yyprefix;
 	  char *yymsg;
-	  int yyx;
+	  int yyx, yycount;
 
+	  yycount = 0;
 	  /* Start YYX at -YYN if negative to avoid negative indexes in
 	     YYCHECK.  */
-	  int yyxbegin = yyn < 0 ? -yyn : 0;
-
-	  /* Stay within bounds of both yycheck and yytname.  */
-	  int yychecklim = YYLAST - yyn;
-	  int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
-	  int yycount = 0;
-
-	  yyprefix = ", expecting ";
-	  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
+	  for (yyx = yyn < 0 ? -yyn : 0;
+	       yyx < (int) (sizeof (yytname) / sizeof (char *)); yyx++)
 	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
-	      {
-		yysize += yystrlen (yyprefix) + yystrlen (yytname [yyx]);
-		yycount += 1;
-		if (yycount == 5)
-		  {
-		    yysize = 0;
-		    break;
-		  }
-	      }
-	  yysize += (sizeof ("syntax error, unexpected ")
-		     + yystrlen (yytname[yytype]));
+	      yysize += yystrlen (yytname[yyx]) + 15, yycount++;
+	  yysize += yystrlen ("parse error, unexpected ") + 1;
+	  yysize += yystrlen (yytname[yytype]);
 	  yymsg = (char *) YYSTACK_ALLOC (yysize);
 	  if (yymsg != 0)
 	    {
-	      char *yyp = yystpcpy (yymsg, "syntax error, unexpected ");
+	      char *yyp = yystpcpy (yymsg, "parse error, unexpected ");
 	      yyp = yystpcpy (yyp, yytname[yytype]);
 
 	      if (yycount < 5)
 		{
-		  yyprefix = ", expecting ";
-		  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
+		  yycount = 0;
+		  for (yyx = yyn < 0 ? -yyn : 0;
+		       yyx < (int) (sizeof (yytname) / sizeof (char *));
+		       yyx++)
 		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
 		      {
-			yyp = yystpcpy (yyp, yyprefix);
+			const char *yyq = ! yycount ? ", expecting " : " or ";
+			yyp = yystpcpy (yyp, yyq);
 			yyp = yystpcpy (yyp, yytname[yyx]);
-			yyprefix = " or ";
+			yycount++;
 		      }
 		}
 	      yyerror (yymsg);
 	      YYSTACK_FREE (yymsg);
 	    }
 	  else
-	    yyerror ("syntax error; also virtual memory exhausted");
+	    yyerror ("parse error; also virtual memory exhausted");
 	}
       else
 #endif /* YYERROR_VERBOSE */
-	yyerror ("syntax error");
+	yyerror ("parse error");
     }
+  goto yyerrlab1;
 
 
-
+/*----------------------------------------------------.
+| yyerrlab1 -- error raised explicitly by an action.  |
+`----------------------------------------------------*/
+yyerrlab1:
   if (yyerrstatus == 3)
     {
       /* If just tried and failed to reuse lookahead token after an
@@ -1714,30 +1660,28 @@ yyerrlab:
 	  /* Pop the error token.  */
           YYPOPSTACK;
 	  /* Pop the rest of the stack.  */
-	  while (yyss < yyssp)
+	  while (yyssp > yyss)
 	    {
-	      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
-	      yydestruct (yystos[*yyssp], yyvsp);
+	      YYDPRINTF ((stderr, "Error: popping "));
+	      YYDSYMPRINT ((stderr,
+			    yystos[*yyssp],
+			    *yyvsp));
+	      YYDPRINTF ((stderr, "\n"));
+	      yydestruct (yystos[*yyssp], *yyvsp);
 	      YYPOPSTACK;
 	    }
 	  YYABORT;
         }
 
-      YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
-      yydestruct (yytoken, &yylval);
+      YYDPRINTF ((stderr, "Discarding token %d (%s).\n",
+		  yychar, yytname[yychar1]));
+      yydestruct (yychar1, yylval);
       yychar = YYEMPTY;
-
     }
 
   /* Else will try to reuse lookahead token after shifting the error
      token.  */
-  goto yyerrlab1;
 
-
-/*----------------------------------------------------.
-| yyerrlab1 -- error raised explicitly by an action.  |
-`----------------------------------------------------*/
-yyerrlab1:
   yyerrstatus = 3;	/* Each real token shifted decrements this.  */
 
   for (;;)
@@ -1758,12 +1702,26 @@ yyerrlab1:
       if (yyssp == yyss)
 	YYABORT;
 
-      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
-      yydestruct (yystos[yystate], yyvsp);
+      YYDPRINTF ((stderr, "Error: popping "));
+      YYDSYMPRINT ((stderr,
+		    yystos[*yyssp], *yyvsp));
+      YYDPRINTF ((stderr, "\n"));
+
+      yydestruct (yystos[yystate], *yyvsp);
       yyvsp--;
       yystate = *--yyssp;
 
-      YY_STACK_PRINT (yyss, yyssp);
+
+#if YYDEBUG
+      if (yydebug)
+	{
+	  short *yyssp1 = yyss - 1;
+	  YYFPRINTF (stderr, "Error: state stack now");
+	  while (yyssp1 != yyssp)
+	    YYFPRINTF (stderr, " %d", *++yyssp1);
+	  YYFPRINTF (stderr, "\n");
+	}
+#endif
     }
 
   if (yyn == YYFINAL)
@@ -1811,6 +1769,6 @@ yyreturn:
 }
 
 
-#line 222 "../iniparse.y"
+#line 222 "/home/RobertC/src/cygwin/setup/iniparse.y"
 
 
