@@ -20,7 +20,7 @@
 
 #if 0
 static const char *cvsid =
-  "\n%%% $Id: localdir.cc,v 2.12 2002/11/09 14:47:54 rbcollins Exp $\n";
+  "\n%%% $Id: localdir.cc,v 2.17 2003/07/30 08:13:09 rbcollins Exp $\n";
 #endif
 
 #include "win32.h"
@@ -39,23 +39,35 @@ static const char *cvsid =
 #include "io_stream.h"
 
 #include "localdir.h"
+#include "UserSettings.h"
 
 #include "threebar.h"
 extern ThreeBarProgressPage Progress;
 extern LogFile * theLog;
-void
-save_local_dir ()
-{
-  io_stream::mkpath_p (PATH_TO_DIR, String ("file://") + local_dir);
 
-  io_stream *f;
-  if (get_root_dir ().size())
+static LocalDirSetting localDir;
+
+void 
+LocalDirSetting::load(){
+  static int inited = 0;
+  if (inited)
+    return;
+  io_stream *f = UserSettings::Instance().settingFileForLoad("last-cache");
+  if (f)
     {
-      f = io_stream::open ("cygfile:///etc/setup/last-cache", "wb");
-      io_stream::remove ("file://last-cache");
+      char localdir[1000];
+      char *fg_ret = f->gets (localdir, 1000);
+      delete f;
+      if (fg_ret)
+        local_dir = String (localdir);
     }
-  else
-    f = io_stream::open ("file://last-cache", "wb");
+  inited = 1;
+}
+
+void 
+LocalDirSetting::save()
+{
+  io_stream *f = UserSettings::Instance().settingFileForSave("last-cache");
   if (f)
     {
       f->write (local_dir.cstr_oneuse(), local_dir.size());
@@ -152,28 +164,6 @@ LocalDirPage::Create ()
   return PropertyPage::Create (NULL, dialog_cmd, IDD_LOCAL_DIR);
 }
 
-void
-LocalDirPage::OnInit ()
-{
-  static int inited = 0;
-  if (!inited)
-    {
-      io_stream *f =
-	io_stream::open ("cygfile:///etc/setup/last-cache", "rt");
-      if (!f)
-	f = io_stream::open ("file://last-cache", "rt");
-      if (f)
-	{
-	  char localdir[1000];
-	  char *fg_ret = f->gets (localdir, 1000);
-	  delete f;
-	  if (fg_ret)
-	    local_dir = String (localdir);
-	}
-      inited = 1;
-    }
-}
-
 void
 LocalDirPage::OnActivate ()
 {
@@ -186,19 +176,18 @@ LocalDirPage::OnNext ()
   HWND h = GetHWND ();
 
   save_dialog (h);
-  save_local_dir ();
+  localDir.save ();
   log (LOG_PLAIN, String ("Selected local directory: ") + local_dir);
   if (SetCurrentDirectoryA (local_dir.cstr_oneuse()))
     {
       if (source == IDC_SOURCE_CWD)
 	{
-	  do_fromcwd (GetInstance (), GetHWND ());
-	  if (next_dialog == IDD_S_LOAD_INI)
+	  if (do_fromcwd (GetInstance (), GetHWND ()))
 	    {
 	      Progress.SetActivateTask (WM_APP_START_SETUP_INI_DOWNLOAD);
 	      return IDD_INSTATUS;
 	    }
-	  return next_dialog;
+	  return IDD_CHOOSE;
 	}
     }
   else
@@ -211,10 +200,5 @@ long
 LocalDirPage::OnBack ()
 {
   save_dialog (GetHWND ());
-  if (source == IDC_SOURCE_DOWNLOAD)
-    {
-      // Downloading only, skip the unix root page
-      return IDD_SOURCE;
-    }
   return 0;
 }
