@@ -18,7 +18,7 @@
    changes, this is the file to change to match it. */
 
 #if 0
-static const char *cvsid = "\n%%% $Id: mount.cc,v 2.15 2003/01/15 22:06:22 maxb Exp $\n";
+static const char *cvsid = "\n%%% $Id: mount.cc,v 2.16 2003/07/11 22:48:14 maxb Exp $\n";
 #endif
 
 #include "win32.h"
@@ -77,7 +77,7 @@ enum
 #ifdef MAINTAINER_FEATURES
 #include "getopt++/GetOption.h"
 #include "getopt++/StringOption.h"
-static StringOption CygwinRegistryNameOption (CYGWIN_INFO_CYGWIN_REGISTRY_NAME, '#', "override-registry-name", "Override registry name to allow parallel installs for testing purposes");
+static StringOption CygwinRegistryNameOption (CYGWIN_INFO_CYGWIN_REGISTRY_NAME, '#', "override-registry-name", "Override registry name to allow parallel installs for testing purposes", false);
 #undef CYGWIN_INFO_CYGWIN_REGISTRY_NAME
 #define CYGWIN_INFO_CYGWIN_REGISTRY_NAME (((std::string)CygwinRegistryNameOption).c_str())
 #endif
