@@ -18,7 +18,7 @@
 
 #if 0
 static const char *cvsid =
-  "\n%%% $Id: net.cc,v 2.12 2002/09/21 09:36:46 rbcollins Exp $\n";
+  "\n%%% $Id: net.cc,v 2.14 2003/07/30 10:41:43 maxb Exp $\n";
 #endif
 
 #include "win32.h"
@@ -33,9 +33,11 @@ static const char *cvsid =
 #include "net.h"
 #include "propsheet.h"
 #include "threebar.h"
+#include "ConnectionSetting.h"
 extern ThreeBarProgressPage Progress;
 
 static int rb[] = { IDC_NET_IE5, IDC_NET_DIRECT, IDC_NET_PROXY, 0 };
+static ConnectionSetting theSetting;
 
 void
 NetPage::CheckIfEnableNext ()
@@ -94,7 +96,8 @@ NetPage::OnInit ()
 {
   HWND h = GetHWND ();
 
-  net_method = IDC_NET_DIRECT;
+  if (!net_method)
+    net_method = IDC_NET_DIRECT;
   load_dialog (h);
   CheckIfEnableNext();
 
