@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001, Robert Collins.
+ * Copyright (c) 2001, 2003 Robert Collins.
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 
 #if 0
 static const char *cvsid =
-  "\n%%% $Id: package_db.cc,v 2.25 2003/03/17 22:23:33 rbcollins Exp $\n";
+  "\n%%% $Id: package_db.cc,v 2.28 2003/07/29 10:07:22 rbcollins Exp $\n";
 #endif
 #include <stdio.h>
 #include <stdlib.h>
@@ -40,6 +40,7 @@ static const char *cvsid =
 #include "package_db.h"
 #include "package_meta.h"
 #include "Exception.h"
+#include "Generic.h"
 
 using namespace std;
 
@@ -348,3 +349,60 @@ packagedb::connectedEnd()
 {
   return dependencyOrderedPackages.end();
 }
+
+void
+packagedb::markUnVisited()
+{
+  for (vector <packagemeta *>::iterator n = packages.begin ();
+       n != packages.end (); ++n)
+    {
+      packagemeta & pkgm = **n;
+      pkgm.visited(false);
+    }
+}
+
+void
+packagedb::setExistence ()
+{
+  /* binary packages */
+  /* Remove packages that are in the db, not installed, and have no 
+     mirror info and are not cached for both binary and source packages. */
+  vector <packagemeta *>::iterator i = packages.begin ();
+  while (i != packages.end ())
+    {
+      packagemeta & pkg = **i;
+      if (!pkg.installed && !pkg.accessible() && 
+     !pkg.sourceAccessible() )
+   {
+   packagemeta *pkgm = *i;
+   delete pkgm;
+      i = packages.erase (i);
+  }
+      else
+ ++i;
+    }
+#if 0
+  /* remove any source packages which are not accessible */
+  vector <packagemeta *>::iterator i = db.sourcePackages.begin();
+  while (i != db.sourcePackages.end())
+    {
+      packagemeta & pkg = **i;
+      if (!packageAccessible (pkg))
+    {
+   packagemeta *pkgm = *i;
+   delete pkgm;
+      i = db.sourcePackages.erase (i);
+    }
+      else
+ ++i;
+    }
+#endif
+}
+
+void
+packagedb::fillMissingCategory ()
+{
+  for_each(packages.begin(), packages.end(), visit_if(mem_fun(&packagemeta::setDefaultCategories), mem_fun(&packagemeta::hasNoCategories)));
+  for_each(packages.begin(), packages.end(), mem_fun(&packagemeta::addToCategoryAll));
+}
+
