@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001, Robert Collins.
+ * Copyright (c) 2001, 2003 Robert Collins.
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -13,8 +13,8 @@
  *
  */
 
-#ifndef _PACKAGE_META_H_
-#define _PACKAGE_META_H_
+#ifndef SETUP_PACKAGE_META_H
+#define SETUP_PACKAGE_META_H
 
 class packageversion;
 class packagemeta;
@@ -31,10 +31,12 @@ class category;
 class packagemeta
 {
 public:
+  static void PrepareForVisit();
+  static void ScanDownloadedFiles();
   packagemeta (packagemeta const &);
   packagemeta (String const &pkgname):name (pkgname), key(pkgname), installed_from (),
   prevtimestamp (0), currtimestamp (0),
-    exptimestamp (0), architecture (), priority()
+    exptimestamp (0), architecture (), priority(), visited_(false)
   {
   }
 
@@ -42,14 +44,19 @@ public:
 	       String const &installedfrom):name (pkgname), key(pkgname),
 	       installed_from (installedfrom),
     prevtimestamp (0), currtimestamp (0),
-    exptimestamp (0), architecture (), priority()
+    exptimestamp (0), architecture (), priority(), visited_(false)
   {
-  };
+  }
 
   ~packagemeta ();
 
   void add_version (packageversion &);
   void set_installed (packageversion &);
+  void visited(bool const &);
+  bool visited() const;
+  bool hasNoCategories() const;
+  void setDefaultCategories();
+  void addToCategoryAll();
 
   class _actions
   {
@@ -74,9 +81,12 @@ public:
   void set_action (packageversion const &default_version);
   void set_action (_actions, packageversion const & default_version);
   void uninstall ();
-  int set_requirements (trusts deftrust = TRUST_CURR, size_t depth = 0);
+  int set_requirements (trusts deftrust, size_t depth);
+  // explicit separation for generic programming.
+  int set_requirements (trusts deftrust = TRUST_CURR) 
+    { return set_requirements (deftrust, 0); }
 
-  String action_caption ();
+  String action_caption () const;
   packageversion trustp (trusts const t) const
   {
     return t == TRUST_PREV ? (prev ? prev : (curr ? curr : installed))
@@ -130,12 +140,22 @@ public:
   bool accessible () const;
   bool sourceAccessible() const;
 
+  void logSelectionStatus() const;
   void logAllVersions() const;
 
 protected:
   packagemeta &operator= (packagemeta const &);
 private:
   String trustLabel(packageversion const &) const;
+  bool visited_;
 };
 
-#endif /* _PACKAGE_META_H_ */
+// for generic programming
+struct SetRequirement {
+   SetRequirement (trusts aTrust) : theTrust (aTrust){}
+   void operator() (packagemeta *pkg) { pkg->set_requirements(theTrust);}
+   trusts theTrust;
+};
+
+
+#endif /* SETUP_PACKAGE_META_H */
