@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001, Gary R. Van Sickle.
+ * Copyright (c) 2001, 2002, 2003 Gary R. Van Sickle.
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@ bool PropertyPage::Create (DLGPROC dlgproc, int TemplateID)
 }
 
 bool
-  PropertyPage::Create (DLGPROC dlgproc,
+PropertyPage::Create (DLGPROC dlgproc,
 			BOOL (*cproc) (HWND h, int id, HWND hwndctl,
 				       UINT code), int TemplateID)
 {
@@ -57,7 +57,7 @@ bool
   psp.dwFlags = 0;
   psp.hInstance = GetInstance ();
   psp.pfnDlgProc = FirstDialogProcReflector;
-  psp.pszTemplate = (LPCSTR) TemplateID;
+  psp.pszTemplate = MAKEINTRESOURCE(TemplateID);
   psp.lParam = (LPARAM) this;
   psp.pfnCallback = NULL;
 
@@ -76,7 +76,7 @@ PropertyPage::FirstDialogProcReflector (HWND hwnd, UINT message,
   if (message != WM_INITDIALOG)
     {
       // Don't handle anything until we get a WM_INITDIALOG message, which
-      // will have our this pointer with it.
+      // will have our 'this' pointer with it.
       return FALSE;
     }
 
@@ -116,9 +116,7 @@ PropertyPage::DialogProc (UINT message, WPARAM wParam, LPARAM lParam)
       {
 	OnInit ();
 
-	// Set header title font of each internal page to MS Sans Serif, Bold, 8 Pt.
-	// This will just silently fail on the first and last pages.
-	SetDlgItemFont(IDC_STATIC_HEADER_TITLE, "MS Sans Serif", 8, FW_BOLD);
+	setTitleFont ();
 
 	// TRUE = Set focus to default control (in wParam).
 	return TRUE;
@@ -159,6 +157,12 @@ PropertyPage::DialogProc (UINT message, WPARAM wParam, LPARAM lParam)
 		GetOwner ()->SetButtons (PSWIZB_BACK | PSWIZB_NEXT);
 	      }
 
+	    if(!wantsActivation())
+	    {
+	      ::SetWindowLong (GetHWND (), DWL_MSGRESULT, -1);
+	      return TRUE;
+	    }
+
 	    OnActivate ();
 
 	    if (unattended_mode) 
@@ -264,3 +268,14 @@ PropertyPage::DialogProc (UINT message, WPARAM wParam, LPARAM lParam)
   // Wasn't handled
   return FALSE;
 }
+
+void
+PropertyPage::setTitleFont ()
+{
+  // These font settings will just silently fail when the resource id
+  // is not present on a page.
+  // Set header title font of each internal page
+  SetDlgItemFont(IDC_STATIC_HEADER_TITLE, "MS Shell Dlg", 8, FW_BOLD);
+  // Set the font for the IDC_STATIC_WELCOME_TITLE
+  SetDlgItemFont(IDC_STATIC_WELCOME_TITLE, "Arial", 12, FW_BOLD);
+}
