@@ -18,7 +18,7 @@
 
 #if 0
 static const char *cvsid =
-  "\n%%% $Id: site.cc,v 2.25 2003/03/10 08:50:16 rbcollins Exp $\n";
+  "\n%%% $Id: site.cc,v 2.31 2003/07/30 08:13:09 rbcollins Exp $\n";
 #endif
 
 #include "site.h"
@@ -46,17 +46,41 @@ static const char *cvsid =
 extern ThreeBarProgressPage Progress;
 
 #include "getopt++/StringOption.h"
+#include "UserSettings.h"
 
 using namespace std;
 
 SiteList site_list;
 SiteList all_site_list;
 
-StringOption SiteOption("", 's', "site", "Download site");
+StringOption SiteOption("", 's', "site", "Download site", false);
 
 /* XXX make into a singleton? */
 static SiteSetting ChosenSites;
 
+void 
+SiteSetting::load()
+{
+  string SiteOptionString = SiteOption;
+  if (SiteOptionString.size()) 
+    registerSavedSite (SiteOptionString.c_str());
+  else
+    getSavedSites ();
+}
+
+void 
+SiteSetting::save()
+{
+  io_stream *f = UserSettings::Instance().settingFileForSave("last-mirror");
+  if (f)
+    {
+      for (SiteList::const_iterator n = site_list.begin ();
+      n != site_list.end (); ++n)
+        f->write ((n->url + "\n").cstr_oneuse(), n->url.size() + 1);
+      delete f;
+    }
+}
+
 void
 site_list_type::init (String const &newurl)
 {
@@ -140,12 +164,7 @@ save_dialog (HWND h)
   if (sel_count > 0)
     {
       int sel_buffer[sel_count];
-      int sel_count2 = SendMessage (listbox, LB_GETSELITEMS, sel_count,
-				    (LPARAM) sel_buffer);
-      if (sel_count != sel_count2)
-	{
-	  NEXT (IDD_SITE);
-	}
+      SendMessage (listbox, LB_GETSELITEMS, sel_count, (LPARAM) sel_buffer);
       for (int n = 0; n < sel_count; n++)
 	{
 	  int mirror =
@@ -155,19 +174,6 @@ save_dialog (HWND h)
     }
 }
 
-void
-save_site_url ()
-{
-  io_stream *f = io_stream::open ("cygfile:///etc/setup/last-mirror", "wb");
-  if (f)
-    {
-      for (SiteList::const_iterator n = site_list.begin ();
-	   n != site_list.end (); ++n)
-        f->write ((n->url + "\n").cstr_oneuse(), n->url.size() + 1);
-      delete f;
-    }
-}
-
 static int
 get_site_list (HINSTANCE h, HWND owner)
 {
@@ -229,8 +235,8 @@ get_site_list (HINSTANCE h, HWND owner)
 #define NOSAVE3 "ftp://gcc.gnu.org/"
 #define NOSAVE3_LEN (sizeof ("ftp://gcc.gnu.org/") - 1)
 
-static void
-register_saved_site (const char * site)
+void
+SiteSetting::registerSavedSite (const char * site)
 {
   site_list_type tempSite(site);
   SiteList::iterator i = find (all_site_list.begin(),
@@ -254,10 +260,10 @@ register_saved_site (const char * site)
     site_list.push_back (tempSite);
 }
 
-static void
-get_saved_sites ()
+void
+SiteSetting::getSavedSites ()
 {
-  io_stream *f = io_stream::open ("cygfile:///etc/setup/last-mirror", "rt");
+  io_stream *f = UserSettings::Instance().settingFileForLoad("last-mirror");
   if (!f)
     return;
 
@@ -273,7 +279,7 @@ get_saved_sites ()
       if (eos < site)
 	continue;
 
-      register_saved_site (site);
+      registerSavedSite (site);
 
     }
   delete f;
@@ -290,9 +296,8 @@ do_download_site_info_thread (void *p)
 
   hinst = (HINSTANCE) (context[0]);
   h = (HWND) (context[1]);
-
-  if (all_site_list.size() == 0
-      && get_site_list (hinst, h))
+  static bool downloaded = false;
+  if (!downloaded && get_site_list (hinst, h))
 	{
 	  // Error: Couldn't download the site info.  Go back to the Net setup page.
 	  MessageBox (h, TEXT ("Can't get list of download sites.\n\
@@ -303,10 +308,13 @@ Make sure your network settings are correct and try again."), NULL, MB_OK);
 				IDD_NET);
 
 	}
-  else
-  // Everything worked, go to the site select page
-  // Tell the progress page that we're done downloading
-  Progress.PostMessage (WM_APP_SITE_INFO_DOWNLOAD_COMPLETE, 0, IDD_SITE);
+  else 
+    {
+      downloaded = true;
+      // Everything worked, go to the site select page
+      // Tell the progress page that we're done downloading
+      Progress.PostMessage (WM_APP_SITE_INFO_DOWNLOAD_COMPLETE, 0, IDD_SITE);
+    }
 
   ExitThread(0);
 }
@@ -329,23 +337,13 @@ bool SitePage::Create ()
   return PropertyPage::Create (IDD_SITE);
 }
 
-void
-SitePage::OnInit ()
-{
-  string SiteOptionString = SiteOption;
-  if (SiteOptionString.size()) 
-    register_saved_site (SiteOptionString.c_str());
-  else
-    get_saved_sites ();
-}
-
 long
 SitePage::OnNext ()
 {
   HWND h = GetHWND ();
 
   save_dialog (h);
-  save_site_url ();
+  ChosenSites.save ();
 
   // Log all the selected URLs from the list.
   for (SiteList::const_iterator n = site_list.begin ();
