@@ -13,8 +13,8 @@
  *
  */
 
-#ifndef _SITE_H_
-#define _SITE_H_
+#ifndef SETUP_SITE_H
+#define SETUP_SITE_H
 
 /* required to parse this file */
 #include <string.h>
@@ -36,7 +36,6 @@ public:
 
   bool Create ();
 
-  virtual void OnInit ();
   virtual void OnActivate ();
   virtual long OnNext ();
   virtual long OnBack ();
@@ -80,12 +79,15 @@ extern SiteList site_list;
 /* potential sites */
 extern SiteList all_site_list;
 
-void save_site_url ();
-
 #include "UserSetting.h"
 class SiteSetting : public UserSetting 
 {
   public:
+    virtual void load();
+    virtual void save();
+  private:
+    void getSavedSites();
+    void registerSavedSite(char const *);
 };
 
-#endif /* _SITE_H_ */
+#endif /* SETUP_SITE_H */
