@@ -19,7 +19,7 @@
 
 #if 0
 static const char *cvsid =
-  "\n%%% $Id: source.cc,v 2.14 2002/11/25 00:41:25 rbcollins Exp $\n";
+  "\n%%% $Id: source.cc,v 2.16 2003/07/30 08:44:51 rbcollins Exp $\n";
 #endif
 
 #include "win32.h"
@@ -32,8 +32,8 @@ static const char *cvsid =
 #include "package_db.h"
 
 #include "source.h"
-
-#include "AntiVirus.h"
+#include "SourceSetting.h"
+static SourceSetting theSetting;
 
 #include "getopt++/BoolOption.h"
 
@@ -114,12 +114,6 @@ SourcePage::OnNext ()
   HWND h = GetHWND ();
 
   save_dialog (h);
-  if (source == IDC_SOURCE_DOWNLOAD)
-    {
-      // If all we're doing is downloading,skip the root directory page
-      return IDD_LOCAL_DIR;
-    }
-
   return 0;
 }
 
@@ -127,8 +121,6 @@ long
 SourcePage::OnBack ()
 {
   save_dialog (GetHWND ());
-  if (!AntiVirus::Show())
-      return IDD_SPLASH;
   return 0;
 }
 
