@@ -26,6 +26,7 @@
 #include "propsheet.h"
 #include "threebar.h"
 #include "cistring.h"
+#include "state.h"
 
 bool ThreeBarProgressPage::Create ()
 {
@@ -135,7 +136,7 @@ ThreeBarProgressPage::OnActivate ()
 }
 
 bool
-  ThreeBarProgressPage::OnMessageApp (UINT uMsg, WPARAM wParam, LPARAM lParam)
+ThreeBarProgressPage::OnMessageApp (UINT uMsg, WPARAM wParam, LPARAM lParam)
 {
   switch (uMsg)
     {
@@ -171,6 +172,18 @@ bool
 	break;
       }
     case WM_APP_INSTALL_THREAD_COMPLETE:
+      {
+	// Install is complete and we want to go on to the postinstall.
+	Window::PostMessage (WM_APP_START_POSTINSTALL);
+	break;
+      }
+    case WM_APP_START_POSTINSTALL:
+      {
+	// Start the postinstall script thread.
+	do_postinstall (GetInstance (), GetHWND ());
+	break;
+      }
+    case WM_APP_POSTINSTALL_THREAD_COMPLETE:
       {
 	// Re-enable and "Push" the Next button
 	GetOwner ()->SetButtons (PSWIZB_NEXT);
@@ -194,14 +207,23 @@ bool
       }
     case WM_APP_SETUP_INI_DOWNLOAD_COMPLETE:
       {
-	if (lParam == IDD_S_FROM_CWD)
+	if (lParam)
 	  {
-	    // There isn't actually a dialog template named this
-	    do_fromcwd (GetInstance (), GetHWND ());
+	    GetOwner ()->SetActivePageByID (IDD_CHOOSE);
 	  }
 	else
 	  {
-	    GetOwner ()->SetActivePageByID (lParam);
+	    if (source == IDC_SOURCE_CWD)
+	      {
+		// There was a setup.ini file (as found by
+		// do_fromcwd), but it had parse errors.
+		GetOwner ()->SetActivePageByID (IDD_SOURCE);
+	      }
+	    else
+	      {
+		// Download failed, try another site.
+		GetOwner ()->SetActivePageByID (IDD_SITE);
+	      }
 	  }
 	break;
       }
