@@ -1,8 +1,5 @@
-#ifndef CINSTALL_WINDOW_H
-#define CINSTALL_WINDOW_H
-
 /*
- * Copyright (c) 2001, Gary R. Van Sickle.
+ * Copyright (c) 2001, 2002, 2003 Gary R. Van Sickle.
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -16,6 +13,9 @@
  *
  */
 
+#ifndef SETUP_WINDOW_H
+#define SETUP_WINDOW_H
+
 // This is the header for the Window class.  It serves both as a window class
 // in its own right and as a base class for other window-like classes (e.g. PropertyPage,
 // PropSheet).
@@ -23,19 +23,23 @@
 #include <windows.h>
 
 class String;
+class RECTWrapper;
 
 class Window
 {
   static ATOM WindowClassAtom;
   static HINSTANCE AppInstance;
 
-  bool RegisterWindowClass ();
+  virtual bool registerWindowClass ();
+protected:
   static LRESULT CALLBACK FirstWindowProcReflector (HWND hwnd, UINT uMsg,
 						    WPARAM wParam,
 						    LPARAM lParam);
+private:
   static LRESULT CALLBACK WindowProcReflector (HWND hwnd, UINT uMsg,
 					       WPARAM wParam, LPARAM lParam);
 
+  // Our Windows(tm) window handle.
   HWND WindowHandle;
 
   Window *Parent;
@@ -50,26 +54,31 @@ protected:
   {
     WindowHandle = h;
   };
+  void setParent(Window *aParent) {Parent = aParent;}
 
 public:
   Window ();
   virtual ~ Window ();
 
+  virtual bool Create (Window * Parent = NULL,
+		       DWORD Style =
+		       WS_OVERLAPPEDWINDOW | WS_VISIBLE | WS_CLIPCHILDREN);
+  
   static void SetAppInstance (HINSTANCE h)
   {
+    // This only has to be called once in the entire app, before
+    // any Windows are created.
     AppInstance = h;
   };
 
   virtual LRESULT WindowProc (UINT uMsg, WPARAM wParam, LPARAM lParam);
   virtual bool MessageLoop ();
 
-  virtual bool Create (Window * Parent = NULL,
-		       DWORD Style =
-		       WS_OVERLAPPEDWINDOW | WS_VISIBLE | WS_CLIPCHILDREN);
   void Show (int State);
 
   HWND GetHWND () const
   {
+    // Ideally this could be hidden from the user completely.
     return WindowHandle;
   };
   HINSTANCE GetInstance () const
@@ -95,12 +104,15 @@ public:
 
   virtual bool OnMessageApp (UINT uMsg, WPARAM wParam, LPARAM lParam)
   {
+    // Not processed by default.  Override in derived classes to
+    // do something with app messages if you need to.
     return false;
   };
 
   virtual bool OnMessageCmd (int id, HWND hwndctl, UINT code)
   {
-    // Not processed.
+    // Not processed by default.  Override in derived classes to
+    // do something with command messages if you need to.
     return false;
   };
 
@@ -112,12 +124,12 @@ public:
 
   // Reposition the window
   bool MoveWindow(long x, long y, long w, long h, bool Repaint = true);
+  bool MoveWindow(const RECTWrapper &r, bool Repaint = true);
 
   // Set the title of the window.
   void SetWindowText (const String & s);
 
   RECT ScreenToClient(const RECT &r) const;
- 
 };
 
-#endif // CINSTALL_WINDOW_H
+#endif /* SETUP_WINDOW_H */
